@@ -3,5 +3,4 @@ from .exceptions import *  # noqa: F403
 from .references import *  # noqa: F403
 from .structures import *  # noqa: F403
 
-
-__all__ = exceptions.__all__ + references.__all__ + structures.__all__  # noqa: F405
+__all__ = exceptions.__all__ + references.__all__ + structures.__all__  # type: ignore[name-defined]  # noqa: F405
