@@ -85,6 +85,11 @@ class OptimadeClient:
     download all.
     """
 
+    property_lists: Dict[str, Dict[str, List[str]]] = defaultdict(dict)
+    """A dictionary containing list of properties served by each database,
+    broken down by entry type, then database.
+    """
+
     headers: Dict = {"User-Agent": f"optimade-python-tools/{__version__}"}
     """Additional HTTP headers."""
 
@@ -97,7 +102,7 @@ class OptimadeClient:
     use_async: bool
     """Whether or not to make all requests asynchronously using asyncio."""
 
-    callbacks: Optional[List[Callable[[str, Dict], None]]] = None
+    callbacks: Optional[List[Callable[[str, Dict], Union[None, Dict]]]] = None
     """A list of callbacks to execute after each successful request, used
     to e.g., write to a file, add results to a database or perform additional
     filtering.
@@ -106,6 +111,11 @@ class OptimadeClient:
     from the JSON response, with keys 'data', 'meta', 'links', 'errors'
     and 'included'.
 
+    Each callback can return a dictionary that can modify the `next_url` with the
+    key `next` and the progress bar with the key `advance_results`.
+    In the case of multiple provided callbacks, only the value returned by the final
+    callback in the stack will be used.
+
     """
 
     silent: bool
@@ -149,7 +159,7 @@ class OptimadeClient:
         http_client: Optional[
             Union[Type[httpx.AsyncClient], Type[requests.Session]]
         ] = None,
-        callbacks: Optional[List[Callable[[str, Dict], None]]] = None,
+        callbacks: Optional[List[Callable[[str, Dict], Union[None, Dict]]]] = None,
     ):
         """Create the OPTIMADE client object.
 
@@ -392,6 +402,67 @@ class OptimadeClient:
             self.count_results[endpoint][filter] = count_results
             return {endpoint: {filter: count_results}}
 
+    def list_properties(
+        self,
+        entry_type: str,
+    ) -> Dict[str, List[str]]:
+        """Returns the list of properties reported at `/info/<entry_type>`
+        for the given entry type, for each database.
+
+        """
+        self._progress = OptimadeClientProgress()
+        if self.silent:
+            self._progress.disable = True
+
+        with self._progress:
+            if not self.silent:
+                self._progress.print(
+                    Panel(
+                        f"Listing properties for [bold yellow]{entry_type}[/bold yellow]",
+                        expand=False,
+                    )
+                )
+            results = self._execute_queries(
+                "",
+                f"info/{entry_type}",
+                paginate=False,
+                page_limit=1,
+                response_fields=[],
+                sort=None,
+            )
+        self.property_lists = {entry_type: {}}
+        for database in results:
+            self.property_lists[entry_type][database] = list(
+                results[database].data.get("properties", {}).keys()  # type: ignore
+            )
+        return self.property_lists[entry_type]
+
+    def search_property(self, query: str, entry_type: str) -> Dict[str, List[str]]:
+        """Searches for the query substring within the listed properties
+        served by each database.
+
+        Parameters:
+            query: The substring to search for.
+            entry_type: The entry type to query.
+
+        Returns:
+            A nested dictionary of matching property lists, arranged by
+            entry type and database.
+
+        """
+        if not self.property_lists:
+            self.list_properties(entry_type=entry_type)
+
+        matching_properties: Dict[str, Dict[str, List[str]]] = {
+            entry_type: defaultdict(list)
+        }
+        if entry_type in self.property_lists:
+            for database in self.property_lists[entry_type]:
+                for property in self.property_lists[entry_type][database]:
+                    if query in property:
+                        matching_properties[entry_type][database].append(property)
+        return matching_properties[entry_type]
+
     def _execute_queries(
         self,
         filter: str,
@@ -931,17 +1002,19 @@ class OptimadeClient:
             "errors": r.get("errors", []),
         }
 
+        callback_response = None
+        if self.callbacks:
+            callback_response = self._execute_callbacks(results, response)
+        callback_response = callback_response or {}
+
         # Advance the progress bar for this provider
         self._progress.update(
             _task,
-            advance=len(results["data"]),
+            advance=callback_response.get("advance_results", len(results["data"])),
             total=results["meta"].get("data_returned", None),
         )
 
-        if self.callbacks:
-            self._execute_callbacks(results, response)
-
-        next_url = results["links"].get("next", None)
+        next_url = callback_response.get("next") or results["links"].get("next", None)
         if isinstance(next_url, dict):
             next_url = next_url.pop("href")
 
@@ -964,16 +1037,20 @@ class OptimadeClient:
 
     def _execute_callbacks(
         self, results: Dict, response: Union[httpx.Response, requests.Response]
-    ) -> None:
+    ) -> Union[None, Dict]:
         """Execute any callbacks registered with the client.
 
         Parameters:
             results: The results from the query.
             response: The full response from the server.
 
+        Returns:
+            Either `None` or the string value returned from the *final* callback.
+
         """
         request_url = str(response.request.url)
         if not self.callbacks:
-            return
+            return None
         for callback in self.callbacks:
-            callback(request_url, results)
+            cb_response = callback(request_url, results)
+        return cb_response
