@@ -7,7 +7,7 @@ __all__ = ("StructureMapper",)
 class StructureMapper(BaseResourceMapper):
     LENGTH_ALIASES = (
         ("elements", "nelements"),
-        ("element_ratios", "nelements"),
+        ("elements_ratios", "nelements"),
         ("cartesian_site_positions", "nsites"),
         ("species_at_sites", "nsites"),
     )
