@@ -22,6 +22,7 @@ from optimade.server.config import CONFIG
 from optimade.server.routers.utils import BASE_URL_PREFIXES, get_base_url
 from optimade.warnings import (
     FieldValueNotRecognized,
+    LocalOptimadeWarning,
     OptimadeWarning,
     QueryParamNotUsed,
     TooManyValues,
@@ -361,6 +362,9 @@ class AddWarnings(BaseHTTPMiddleware):
             warnings._showwarning_orig(message, category, filename, lineno, file, line)  # type: ignore[attr-defined]
             return
 
+        if isinstance(message, LocalOptimadeWarning):
+            return
+
         # Format warning
         try:
             title = str(message.title)
