@@ -1,3 +1,5 @@
+from typing import Any, Dict
+
 from fastapi import APIRouter, Depends, Request
 
 from optimade.models import (
@@ -23,14 +25,14 @@ structures_coll = create_collection(
 
 @router.get(
     "/structures",
-    response_model=StructureResponseMany,
+    response_model=StructureResponseMany if CONFIG.validate_api_response else Dict,
     response_model_exclude_unset=True,
     tags=["Structures"],
     responses=ERROR_RESPONSES,
 )
 def get_structures(
     request: Request, params: EntryListingQueryParams = Depends()
-) -> StructureResponseMany:
+) -> Any:
     return get_entries(
         collection=structures_coll,
         response=StructureResponseMany,
@@ -41,14 +43,14 @@ def get_structures(
 
 @router.get(
     "/structures/{entry_id:path}",
-    response_model=StructureResponseOne,
+    response_model=StructureResponseOne if CONFIG.validate_api_response else Dict,
     response_model_exclude_unset=True,
     tags=["Structures"],
     responses=ERROR_RESPONSES,
 )
 def get_single_structure(
     request: Request, entry_id: str, params: SingleEntryQueryParams = Depends()
-) -> StructureResponseOne:
+) -> Any:
     return get_single_entry(
         collection=structures_coll,
         entry_id=entry_id,
