@@ -79,7 +79,7 @@ _INCLUSIVE_OPERATORS = {
     ),
     DataType.INTEGER: inclusive_ops,
     DataType.FLOAT: (),
-    DataType.LIST: ("HAS", "HAS ALL", "HAS ANY"),
+    DataType.LIST: ("HAS", "HAS ALL", "HAS ANY", "LENGTH"),
 }
 
 exclusive_ops = ("!=", "<", ">")
@@ -108,6 +108,9 @@ _FIELD_SPECIFIC_OVERRIDES = {
             if op != "="
         ],
     },
+    "structure_features": {
+        SupportLevel.OPTIONAL: "LENGTH",
+    },
 }
 
 
