@@ -682,6 +682,8 @@ class ImplementationValidator:
                 else:
                     _vals = [f"{val}" for val in _vals]
                 _test_value = ",".join(_vals)
+            elif operator == "LENGTH":
+                _test_value = f"{len(test_value)}"
             else:
                 if isinstance(test_value[0], str):
                     _test_value = f'"{test_value[0]}"'
@@ -1238,7 +1240,7 @@ class ImplementationValidator:
             expected_status_code = [404, 400]
 
         self._get_endpoint(
-            "v123123", expected_status_code=expected_status_code, optional=True
+            "v123123/info", expected_status_code=expected_status_code, optional=True
         )
 
     @test_case
